/*
 * [ANZACDay.java]
 *
 * Summary: Calculate when ANZAC day day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * Calculate when ANZAC day day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @see AustraliaDay
 * @since 1999
 */
public final class ANZACDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://en.wikipedia.org/wiki/ANZAC_Day";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1915;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "ANZAC Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Celebrated April 25 in Australia and New Zealand to\n" +
               "commemorate landing at Gallipoli in Turkey\n" +
               "during World War I on 1915-04-25.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 4, 25 ), shift );
        }// end when.
    }
