/*
 * [ColumbusDay.java]
 *
 * Summary: calculate when Columbus day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * calculate when Columbus day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class ColumbusDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.usis.usemb.se/Holidays/celebrate/Columbus.htm";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1905;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Columbus Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "1905 .. 1970 -> October 12\n"
               + "1971 .. now  -> Second Monday in October.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        if ( 1905 <= year && year <= 1970 )
            {
            return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 10, 12 ),
                    shift );
            }
        if ( 1971 <= year )
            {
            return BigDate.ordinalOfnthXXXDay( 2, BigDate.MONDAY, year, BigDate.OCT );
            }
        return BigDate.NULL_ORDINAL;
        }// end when.
    }
