/*
 * [WashingtonsBirthday.java]
 *
 * Summary: Calculate when Washington's Birthday occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * Calculate when Washington's Birthday occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class WashingtonsBirthday extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1796;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Washington\u2019s Birthday";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Celebrated as third Monday in February.\n"
               + "Replaced by Presidents day in 1971.\n"
               + "Washington\u2019s actual birthday is February 22.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) || ( base == PROCLAIMED
                                             && year >= 1971 ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 3, BigDate.MONDAY, year, BigDate.FEB );
        }// end when.
    }
