/*
 * [WorldAIDSDay.java]
 *
 * Summary: Calculate when World AIDS day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * Calculate when World AIDS day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class WorldAIDSDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://en.wikipedia.org/wiki/World_AIDS_Day";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1988;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "World AIDS Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "December 1";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 12, 1 ),
                shift );
        }// end when.
    }
